"""Top-level package for NFE Parser."""

__author__ = """Goncalo Magno"""
__email__ = "goncalo@gmagno.dev"
__version__ = "0.4.0"
